#!/bin/bash

# script to build eCos for Comtrol DeviceMaster RTS.  If they're not
# already configured, it tries to make educated guesses about
# locations of arm-elf toolchain, eCos repository, ecosconfig.

# assumes newTree-2.0 script is in current directory

#============================================================
# do we have arm-elf toolchain in PATH?

if [ -z $(which arm-elf-gcc 2>/dev/null) ]; then
    echo "arm-elf-gcc not found in PATH"
    if [ ! -d gnutools/bin ]; then
        if expr $(uname) : CYGWIN >/dev/null; then
            Tarfile=$(echo arm-elf-*cygwin.tar.gz)
        else
            Tarfile=$(echo arm-elf-*linux.tar.gz)
        fi
        if [ -f "$Tarfile" ]; then
            read -e -p "Found $Tarfile. Unpack it and use it? [y]/n: " answer
            case "$answer" in
                ""|[yY]|[yes]|[YES]|[Yes])
                    tar xf "$Tarfile"
                ;;
            esac
        fi
    fi

    if [ -x gnutools/bin/arm-elf-gcc -o -x gnutools/bin/arm-elf-gcc.exe ]; then
        echo "arm-elf-gcc found in $PWD/gnutools/bin, adding that to PATH."
        PATH="$PATH:$PWD/gnutools/bin"
    fi
fi

GccPath="$(which arm-elf-gcc 2>/dev/null)"

if [ -z "$GccPath" ]; then
    echo "Error: No arm-elf-gcc found in PATH."
    exit 1
fi

echo "using cross-compiler at $GccPath"

#============================================================
# is there an ecosconfig executable in the PATH?

if [ -z $(which ecosconfig 2>/dev/null) ]; then
    Ecosconfig=$(echo ecosconfig*)
    echo "Ecosconfig='$Ecosconfig'"
    if [ -f "$Ecosconfig" ]; then
        echo "ecosconfig not found in PATH, but found $PWD/$Ecosconfig"
        read -e -p "Add $PWD to PATH and use $Ecosconfig? [y]/n: " answer
            case "$answer" in
                ""|[yY]|[yes]|[YES]|[Yes])
                    chmod +x "$Ecosconfig"
                    [ "$Ecosconfig" != "ecosconfig" -a "$Ecosconfig" != "ecosconfig.exe" ] && mv $Ecosconfig ecosconfig
                    PATH="$PATH:$PWD"
                ;;
            esac
    fi
fi

EcosconfigPath="$(which ecosconfig 2>/dev/null)"

if [ -z "$EcosconfigPath" ]; then
    echo "Error: no ecosconfig executable in PATH"
    exit 1
fi

echo "using ecosconfig at $EcosconfigPath"


#============================================================
# Is ECOS_REPOSITORY set?

if [ -z "${ECOS_REPOSITORY}" ]; then
    echo "ECOS_REPOSITORY is not set or is empty."
    # look for source tree or tarfile in current directory
    if [ -d ecos2src-sdk ]; then
        echo "Found source tree in ecos2src-sdk, using that as ECOS_REPOSITORY"
        export ECOS_REPOSITORY=$PWD/ecos2src-sdk
    elif [ -f ecos2src-sdk.tar.gz ]; then
        echo "ecos2src-sdk directory not found, but ecos2src-sdk.tar.gz is found."
        read -e -p "unpack ecos2src-sdk.tar.gz and use that? [y]/n: " answer
        case "$answer" in
            ""|[yY]|[yes]|[YES]|[Yes])
                tar xf ecos2src-sdk.tar.gz
                export ECOS_REPOSITORY=$PWD/ecos2src-sdk
                ;;
        esac
    fi
fi

if [ -z "${ECOS_REPOSITORY}" ]; then
    echo "Error: unable to figure out what to use for ECOS_REPOSITORY."
    echo "       please set ECOS_REPOSITORY and try again."
    exit 1
fi

echo "using eCos repository at $ECOS_REPOSITORY."

if [ ! -f "$ECOS_REPOSITORY/ecos.db" ]; then
    echo "$ECOS_REPOSITORY/ecos.db not found." 
    echo "verify ECOS_REPOSITORY and try again."
    exit 1
fi 

#============================================================
# Create an empty build directory

rm -rf ecos-build
mkdir ecos-build

#============================================================
# Fix Cygwin mounts if we need to

function textmount {
    Dir="$1"
    Mode=$(cygpath -M "$Dir")
    [ "$Mode" != "$Dir: text" ] && return 0
    echo "remounting $Dir in textmode to avoid build problems due to TCL quirks."
    mount -ftu $(cygpath -m "$Dir") "$Dir"
}

if expr $(uname) : CYGWIN >/dev/null; then
    textmount "$ECOS_REPOSITORY"
    textmount ecos_build
fi

#============================================================
# Make sure we've got a copy of newTree-2.0

if [ ! -x newTree-2.0 ]; then
    if [ -f newTree-2.0 ]; then
        chmod +x newTree-2.0
    else
        echo "Error: newTree-2.0 shell script not found in current directory."
        exit 1
    fi
fi

#============================================================
# build it

cd ecos-build
../newTree-2.0 && make
